@@ -9,7 +9,10 @@ Usage::
 
     from mypy_boto3_codebuild import CodeBuildClient
     from mypy_boto3_codebuild.paginator import (
+        DescribeCodeCoveragesPaginator,
         DescribeTestCasesPaginator,
+        ListBuildBatchesPaginator,
+        ListBuildBatchesForProjectPaginator,
         ListBuildsPaginator,
         ListBuildsForProjectPaginator,
         ListProjectsPaginator,
@@ -22,7 +25,10 @@ Usage::
 
     client: CodeBuildClient = boto3.client("codebuild")
 
+    describe_code_coverages_paginator: DescribeCodeCoveragesPaginator = client.get_paginator("describe_code_coverages")
     describe_test_cases_paginator: DescribeTestCasesPaginator = client.get_paginator("describe_test_cases")
+    list_build_batches_paginator: ListBuildBatchesPaginator = client.get_paginator("list_build_batches")
+    list_build_batches_for_project_paginator: ListBuildBatchesForProjectPaginator = client.get_paginator("list_build_batches_for_project")
     list_builds_paginator: ListBuildsPaginator = client.get_paginator("list_builds")
     list_builds_for_project_paginator: ListBuildsForProjectPaginator = client.get_paginator("list_builds_for_project")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
@@ -39,7 +45,11 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_codebuild.type_defs import (
+    BuildBatchFilterTypeDef,
+    DescribeCodeCoveragesOutputTypeDef,
     DescribeTestCasesOutputTypeDef,
+    ListBuildBatchesForProjectOutputTypeDef,
+    ListBuildBatchesOutputTypeDef,
     ListBuildsForProjectOutputTypeDef,
     ListBuildsOutputTypeDef,
     ListProjectsOutputTypeDef,
@@ -60,7 +70,10 @@ else:
 
 
 __all__ = (
+    "DescribeCodeCoveragesPaginator",
     "DescribeTestCasesPaginator",
+    "ListBuildBatchesPaginator",
+    "ListBuildBatchesForProjectPaginator",
     "ListBuildsPaginator",
     "ListBuildsForProjectPaginator",
     "ListProjectsPaginator",
@@ -72,9 +85,28 @@ __all__ = (
 )
 
 
+class DescribeCodeCoveragesPaginator(Boto3Paginator):
+    """
+    [Paginator.DescribeCodeCoverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+    """
+
+    def paginate(
+        self,
+        reportArn: str,
+        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortBy: Literal["LINE_COVERAGE_PERCENTAGE", "FILE_PATH"] = None,
+        minLineCoveragePercentage: float = None,
+        maxLineCoveragePercentage: float = None,
+        PaginationConfig: PaginatorConfigTypeDef = None,
+    ) -> Iterator[DescribeCodeCoveragesOutputTypeDef]:
+        """
+        [DescribeCodeCoverages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
+        """
+
+
 class DescribeTestCasesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+    [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
     """
 
     def paginate(
@@ -84,13 +116,46 @@ class DescribeTestCasesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeTestCasesOutputTypeDef]:
         """
-        [DescribeTestCases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        [DescribeTestCases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        """
+
+
+class ListBuildBatchesPaginator(Boto3Paginator):
+    """
+    [Paginator.ListBuildBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+    """
+
+    def paginate(
+        self,
+        filter: BuildBatchFilterTypeDef = None,
+        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        PaginationConfig: PaginatorConfigTypeDef = None,
+    ) -> Iterator[ListBuildBatchesOutputTypeDef]:
+        """
+        [ListBuildBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
+        """
+
+
+class ListBuildBatchesForProjectPaginator(Boto3Paginator):
+    """
+    [Paginator.ListBuildBatchesForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+    """
+
+    def paginate(
+        self,
+        projectName: str = None,
+        filter: BuildBatchFilterTypeDef = None,
+        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        PaginationConfig: PaginatorConfigTypeDef = None,
+    ) -> Iterator[ListBuildBatchesForProjectOutputTypeDef]:
+        """
+        [ListBuildBatchesForProject.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
         """
 
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+    [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
     """
 
     def paginate(
@@ -99,13 +164,13 @@ class ListBuildsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBuildsOutputTypeDef]:
         """
-        [ListBuilds.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [ListBuilds.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+    [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
     """
 
     def paginate(
@@ -115,13 +180,13 @@ class ListBuildsForProjectPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBuildsForProjectOutputTypeDef]:
         """
-        [ListBuildsForProject.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [ListBuildsForProject.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+    [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
     """
 
     def paginate(
@@ -131,13 +196,13 @@ class ListProjectsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProjectsOutputTypeDef]:
         """
-        [ListProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [ListProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         """
 
 
 class ListReportGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+    [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
     """
 
     def paginate(
@@ -147,13 +212,13 @@ class ListReportGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportGroupsOutputTypeDef]:
         """
-        [ListReportGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
+        [ListReportGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
         """
 
 
 class ListReportsPaginator(Boto3Paginator):
     """
-    [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+    [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
     """
 
     def paginate(
@@ -163,13 +228,13 @@ class ListReportsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportsOutputTypeDef]:
         """
-        [ListReports.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
+        [ListReports.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
         """
 
 
 class ListReportsForReportGroupPaginator(Boto3Paginator):
     """
-    [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+    [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
     """
 
     def paginate(
@@ -180,13 +245,13 @@ class ListReportsForReportGroupPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportsForReportGroupOutputTypeDef]:
         """
-        [ListReportsForReportGroup.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
+        [ListReportsForReportGroup.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
         """
 
 
 class ListSharedProjectsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+    [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
     """
 
     def paginate(
@@ -196,13 +261,13 @@ class ListSharedProjectsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSharedProjectsOutputTypeDef]:
         """
-        [ListSharedProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
+        [ListSharedProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
         """
 
 
 class ListSharedReportGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+    [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
     """
 
     def paginate(
@@ -212,5 +277,5 @@ class ListSharedReportGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSharedReportGroupsOutputTypeDef]:
         """
-        [ListSharedReportGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
+        [ListSharedReportGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.32/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
         """
